@@ -16,11 +16,12 @@ import google.protobuf.message
 
 ProtobufMessage = google.protobuf.message.Message
 
-import nibiru.common  # noqa
+import nibiru.exceptions  # noqa
 import nibiru.msg  # noqa
-from nibiru.client import GrpcClient  # noqa
-from nibiru.common import Coin, Direction, PoolAsset, Side, TxConfig, TxType  # noqa
+import nibiru.pytypes  # noqa
+from nibiru.grpc_client import GrpcClient  # noqa
 from nibiru.network import Network  # noqa
+from nibiru.pytypes import Coin, Direction, PoolAsset, Side, TxConfig, TxType  # noqa
 from nibiru.sdk import Sdk  # noqa
 from nibiru.transaction import Transaction  # noqa
 from nibiru.wallet import Address, PrivateKey, PublicKey  # noqa
