@@ -23,9 +23,8 @@ class EventType(Enum):
 
     # Vpool events
     ReserveSnapshotSavedEvent = vpool_events.ReserveSnapshotSavedEvent
-    SwapQuoteForBaseEvent = vpool_events.SwapQuoteForBaseEvent
-    SwapBaseForQuoteEvent = vpool_events.SwapBaseForQuoteEvent
-    MarkPriceChanged = vpool_events.MarkPriceChanged
+    SwapOnVpoolEvent = vpool_events.SwapOnVpoolEvent
+    MarkPriceChanged = vpool_events.MarkPriceChangedEvent
 
     # # Dex event
     # PoolJoinedEvent = dex_events.EventPoolJoined
